@@ -27,16 +27,30 @@ G_BEGIN_DECLS
 
 /*
  * A theme should define at least the following styles to work well with the included .lang files:
+ * 
+ * - Base-N Integer
+ * - Character
+ * - Comment
+ * - Data Type
+ * - Function
+ * - Decimal
+ * - Floating Point
+ * - Keyword
+ * - Preprocessor
+ * - String
+ * - Specials
+ * - Others
+ * - Others 2
+ * - Others 3
  *
- * TODO
  *
  * The default theme defines all of them.
  *
  */
 
 #define GTK_TYPE_SOURCE_STYLE_SCHEME             (gtk_source_style_scheme_get_type ())
-#define GTK_STYLE_SOURCE_SCHEME(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_SOURCE_STYLE_SCHEME, GtkSourceStyleScheme))
-#define GTK_STYLE_SOURCE_SCHEME_CLASS(vtable)    (G_TYPE_CHECK_CLASS_CAST ((vtable), GTK_TYPE_SOURCE_STYLE_SCHEME, GtkSourceStyleSchemeClass))
+#define GTK_SOURCE_STYLE_SCHEME(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_SOURCE_STYLE_SCHEME, GtkSourceStyleScheme))
+#define GTK_SOURCE_STYLE_SCHEME_CLASS(vtable)    (G_TYPE_CHECK_CLASS_CAST ((vtable), GTK_TYPE_SOURCE_STYLE_SCHEME, GtkSourceStyleSchemeClass))
 #define GTK_IS_SOURCE_STYLE_SCHEME(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_SOURCE_STYLE_SCHEME))
 #define GTK_IS_SOURCE_STYLE_SCHEME_CLASS(vtable) (G_TYPE_CHECK_CLASS_TYPE ((vtable), GTK_TYPE_SOURCE_STYLE_SCHEME))
 #define GTK_SOURCE_STYLE_SCHEME_GET_CLASS(inst)  (G_TYPE_INSTANCE_GET_INTERFACE ((inst), GTK_TYPE_SOURCE_STYLE_SCHEME, GtkSourceStyleSchemeClass))
